/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("com.ibm.team.process.web.ui.internal.ProjectAreaListApplication");

dojo.require("net.jazz.ajax.ui.internal.Dialog");
dojo.require("net.jazz.ajax.ui.PlatformUI");

dojo.require("com.ibm.team.repository.web.ui.internal._JazzApplication");

dojo.require("com.ibm.team.repository.web.client.init.InitializationData");
dojo.require("com.ibm.team.repository.web.client.internal.RepositoryClient");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");

var PlatformUI				= net.jazz.ajax.ui.PlatformUI;
var RepositoryClient 		= com.ibm.team.repository.web.client.internal.RepositoryClient;
var ServiceResponseHandler	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var InitializationData      = com.ibm.team.repository.web.client.init.InitializationData;
var Dialog                  = net.jazz.ajax.ui.internal.Dialog;

dojo.declare(
	"com.ibm.team.process.web.ui.internal.ProjectAreaListApplication",
	com.ibm.team.repository.web.ui.internal._JazzApplication, {
	
	init: function() {
		var srh = new ServiceResponseHandler(
			this, "_fetchInitDataSuccess", "_fetchInitDataFailure");
		RepositoryClient.getInitializationData(srh);
	},
	
	_fetchInitDataSuccess: function(initializationData) {
		InitializationData._load(initializationData);
		
		// set the global var for the logged-in contributor
		try {
			dojo.setObject(
				"com.ibm.team.repository.web.client.internal.AUTHENTICATED_CONTRIBUTOR",
				InitializationData.get("com.ibm.team.repository.service.currentContributorInitializer").currentContributor);
		} catch (e) {
			document.title = "Error Loading User";
			var content = document.createElement("div");
			content.style.padding = "1em";
			var mainContent = document.createElement("div");
			mainContent.appendChild(document.createTextNode("An error was encountered attempting to fetch the authenticated user from the repository.  This is often caused by a problem connecting to the database.  Please contact your administator."));
			var adminContent = document.createElement("div");
			adminContent.style.paddingTop = "8px";
			adminContent.appendChild(document.createTextNode("If you have JazzAdmins privileges you can investigate the problem in the "));
			var link = document.createElement("a");
			link.href = net.jazz.ajax._contextRoot + "/admin";
			link.appendChild(document.createTextNode("Jazz Admin Web UI"));
			adminContent.appendChild(link);
			adminContent.appendChild(document.createTextNode("."));
			content.appendChild(mainContent);
			content.appendChild(adminContent);
			var dialog = new Dialog({primaryTitle: "Error Loading User", contentNode: content});
			return;
		}
			
		// store the configuration properties in global vars with corresponding
		// names
		var configProperties = InitializationData.get("com.ibm.team.repository.service.configPropertyInitializer");
		for (var propName in configProperties) {
			var propVal = configProperties[propName];
			dojo.setObject(propName, propVal);
		}
		
		// initialize the UI
		var args = {
			label: "Project Areas",
			showLoginPanel: true
		};
		this._initUI(args);
		PlatformUI.getWorkbench()._setDefaultTitle("IBM Rational Team Concert");
		ProjectAreaList.superclass.start.call(this);
	},
	
	_fetchInitDataFailure: function(errorObj) {
		if (errorObj.status == 401) {
			var content = document.createElement("div");
			content.style.padding = "1em";
			content.appendChild(document.createTextNode("You either did not provide login credentials or your account does not have permission to access the web ui."));
			if (dojo.cookie("JazzFormAuth") != null) {
				content.appendChild(document.createTextNode(" Click the button below to attempt to login again."));
				var button = document.createElement("button");
				button.appendChild(document.createTextNode("Login Again"));
				var buttonDiv = document.createElement("div");
				buttonDiv.style.textAlign = "center";
				buttonDiv.style.marginTop = "1em";
				buttonDiv.appendChild(button);
				content.appendChild(buttonDiv);
				var dialog = new Dialog({primaryTitle: "Access Denied", contentNode: content});
				dojo.connect(button,"onclick",dialog,function (e) {
					dojo.stopEvent(e);
					this.close();
					var bindArgs = {
				        url: dojo.baseUrl + "../../auth/logout",
				        content: { },
						handle: dojo.hitch(this, function(response, ioArgs){
							window.location.reload();
				        })
				    };
				    dojo.xhrPost(bindArgs);
				});
			}
			else {
				content.appendChild(document.createTextNode(" If you have not logged in, click the button below to reload the page and attempt authentication again.  If you are logged in, you will need to close your browser before you can attempt to login as another user."));
				var button = document.createElement("button");
				button.appendChild(document.createTextNode("Reload"));
				var buttonDiv = document.createElement("div");
				buttonDiv.style.textAlign = "center";
				buttonDiv.style.marginTop = "1em";
				buttonDiv.appendChild(button);
				content.appendChild(buttonDiv);
				var dialog = new Dialog({primaryTitle: "Access Denied", contentNode: content});
				dojo.connect(button,"onclick",dialog,function (e) {
					dojo.stopEvent(e);
					this.close();
					window.location.reload();
				});
			}
		}
		else {
			var content = document.createElement("div");
			content.style.padding = "1em";
			content.appendChild(document.createTextNode(errorObj.message));
			var button = document.createElement("button");
			button.appendChild(document.createTextNode("OK"));
			var buttonDiv = document.createElement("div");
			buttonDiv.style.textAlign = "center";
			buttonDiv.style.marginTop = "1em";
			buttonDiv.appendChild(button);
			content.appendChild(buttonDiv);
			var dialog = new Dialog({primaryTitle: "Error", contentNode: content});
			dojo.connect(button,"onclick",dialog,function (e) {
				dojo.stopEvent(e);
				this.close();
			});
		}
	}
});

var ProjectAreaList = com.ibm.team.process.web.ui.internal.ProjectAreaListApplication;

})();
